PALM-meteo: palmmeteo.library Namespace Reference

PALM-meteo

Classes | Functions | Variables
palmmeteo.library Namespace Reference

## Classes
class | InputUnitsInfo
class | LatLonRegularGrid
class | LoadedQuantity
class | PalmPhysics
class | QuantityCalculator
class | TriRegridder
class | UnitConverter

## Functions
def | barycentric (tri, pt, isimp)
def | verify_palm_hinterp (regridder, lats, lons)
def | parse_linspace (space, name, maxerr)

## Variables
| utc = datetime.timezone.utc
| utcdefault = lambda dt: dt.replace(tzinfo=utc) if dt.tzinfo is None else dt

## Function Documentation

## ◆ barycentric()

def palmmeteo.library.barycentric | ( |  | tri,
|  |  | pt,
|  |  | isimp
| ) |  |

    Calculate barycentric coordinates of a multi-dimensional point set
    within a triangulation.

    :param pt:      selection of points (multi-dimensional)
    :param isimp:   selection of simplices (same dims as pt)

## ◆ parse_linspace()

def palmmeteo.library.parse_linspace | ( |  | space,
|  |  | name,
|  |  | maxerr
| ) |  |

    Verifies that a vector is evenly-spaced and returns the parameters
    of such spacing.

## ◆ verify_palm_hinterp()

def palmmeteo.library.verify_palm_hinterp | ( |  | regridder,
|  |  | lats,
|  |  | lons
| ) |  |

    Regrids source lat+lon coordinates to PALM coordinates using the regridder and verifies the result.

## Variable Documentation

## ◆ utc

palmmeteo.library.utc = datetime.timezone.utc

## ◆ utcdefault

palmmeteo.library.utcdefault = lambda dt: dt.replace(tzinfo=utc) if dt.tzinfo is None else dt